package org.ow2.util.ee.metadata.car.impl.configurator;

import java.util.Set;

import org.ow2.util.ee.metadata.car.api.ICarClassMetadata;
import org.ow2.util.ee.metadata.car.api.ICarFieldMetadata;
import org.ow2.util.ee.metadata.car.api.ICarMethodMetadata;
import org.ow2.util.ee.metadata.car.impl.CarClassMetadata;
import org.ow2.util.ee.metadata.car.impl.CarDeployableMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.CommonClassMetadataConfigurator;
import org.ow2.util.scan.api.configurator.IFieldConfigurator;
import org.ow2.util.scan.api.configurator.IMethodConfigurator;
import org.ow2.util.scan.api.metadata.structures.JClass;
import org.ow2.util.scan.api.metadata.structures.JField;
import org.ow2.util.scan.api.metadata.structures.JMethod;


/**
 * WarClassMetadataConfigurator.
 * @author Gael Lalire
 */
public class CarClassMetadataConfigurator extends
        CommonClassMetadataConfigurator<ICarClassMetadata, ICarMethodMetadata, ICarFieldMetadata> {

    /**
     * WarClassMetadataConfigurator.
     * @param jClass signature
     * @param warArchiveMetadata parent
     */
    public CarClassMetadataConfigurator(final JClass jClass, final CarDeployableMetadata warArchiveMetadata) {
        super(new CarClassMetadata(jClass, warArchiveMetadata));
        registerAnnotationVisitor();
    }

    /**
     * @param jField signature
     * @return configurator
     */
    @Override
    protected IFieldConfigurator createFieldMetadataConfigurator(final JField jField) {
        return new CarFieldMetadataConfigurator(jField, getClassMetadata());
    }

    /**
     * @param jMethod signature
     * @return configurator
     */
    @Override
    protected IMethodConfigurator createMethodMetadataConfigurator(final JMethod jMethod) {
        return new CarMethodMetadataConfigurator(jMethod, getClassMetadata());
    }

    /**
     * add class to archive.
     * @param referencedClasses you may fill this set with class referenced in current metadata
     */
    @Override
    public void configurationComplete(final Set<String> referencedClasses) {
       ICarClassMetadata warClassMetadata = getClassMetadata();
       warClassMetadata.getCarDeployableMetadata().addCarClassMetadata(warClassMetadata);
       super.configurationComplete(referencedClasses);
    }

}
